package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````T!<``#0```"`D0````(`!30`(``)
M`"@`&P`:``$``'"HB0``J(D``*B)```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``$P``
M`!,````$`````0````$```````````````````"TB0``M(D```4```````$`
M`0```*R-``"LC0$`K(T!`)0"``"H$@``!@```````0`"````M(T``+2-`0"T
MC0$`$`$``!`!```&````!`````0```!H`0``:`$``&@!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DK(T`
M`*R-`0"LC0$`5`(``%0"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,P``
M!````!0````#````1TY5`$&1?.RT456.+!UA7UUI6]$>8K'D!````!`````!
M````1TY5```````#`````@`````````1````3`````@````(`````9`0!"5`
M!(`H@``%H(90A(`!```+*`2,.*`218H```A,````30```%````!4````50``
M`%T```!>````7P```&$```!B````9````&4```!F````9P```&H`````````
M``````&O-.ANQ=\?SMY'+6M_FGPNQ9NV=E0\E"#_Y`[59-1\V7%8'.)'Q@%"
M^M>'K$OCP+KCDGQ8[Y=YPN4_+/JA;&"S`8MO:PE#UF>OS&9"1=7LB0=PTPT4
MXI[:S>.>,V+;[16,)<P-.I<+?ZF<F[[:5QO@IP(*:QJ>4*/@^TD`````````
M`````````````````"`2`````````P`+````````D`$```````,`%@!``@``
M```````````2````X0(`````````````$@```+4"`````````````"(```#Z
M`@`````````````1````H0,`````````````$@````$``````````````"``
M``"F`0`````````````2````E`(`````````````$@```-("````````````
M`!(```#X```````````````2````%@,`````````````$0```%L"````````
M`````!(```!<`0`````````````2````1P(`````````````$@```'0`````
M`````````!(```#S```````````````2````8@(`````````````$@```"0"
M`````````````!(```#J`0`````````````2````!`,`````````````$@``
M`/L!`````````````!(````(`@`````````````2````T0``````````````
M$0```$X!`````````````!(```"S```````````````1````'`$`````````
M````$@```)L"`````````````!(```"-`@`````````````1````B@$`````
M````````$@```+(!`````````````!(```!W`0`````````````2````>P(`
M````````````$@```*L!`````````````!(```"#`0`````````````2````
MZ`(`````````````$@```"H!`````````````!(````=```````````````@
M````'0(`````````````$@```-0!`````````````!(````R`@``````````
M```2````5```````````````$@```*0"`````````````!(```"#````````
M```````2````E0$`````````````$@```,0"`````````````!(```"/````
M```````````2````0P$`````````````$@````("`````````````!(````Y
M`@`````````````2````"0$`````````````$@```$8``````````````!(`
M``#]```````````````2````;`$`````````````$@```$T"````````````
M`!(```#````````````````2````%@(`````````````$@```-H"````````
M`````!(```#<```````````````2````*P(`````````````$@```&,`````
M`````````!(```#[`@`````````````A````JP(`````````````$@```*0`
M`````````````!(````Z`0`````````````2````+```````````````(```
M`/P"`````````````!$```"#`@`````````````2````V0$`````````````
M$@```!`"`````````````!(```#.`0`````````````2````<`(`````````
M````$@```.$!`````````````!(```"Z`0`````````````2````O@,``%2@
M`0``````$``7`*H#``"@.```<`$``!(`#0#B`P``9"T``'@(```2``T`]0(`
M`"`5``"P`@``$@`-`'`#``"H(0``!````!(`#0"!`P``0)`!```````0`!<`
M?@0``*PA``"4`@``$@`-`+0$``#<-0``Q`(``!(`#0!J!```0)`!```````0
M`!<`R0,``$`D```H````$@`-`.\#``"P1@``&`$``!(`#0`'!```H$D```0`
M```1``\`1@0``%2@`0``````$``7`$L$``!4H`$``````!``%P!V!```7"``
M`%`````2``T`BP0``/PK``!H`0``$@`-`)T$```H*P``O````!(`#0#Z`P``
M`)`!```````0`!8`U@,``&@D```D`0``$@`-`+8#``!`D`$``````!``%@`\
M!```/)`!``0````1`!8`8`,``(!)```$````$@`-`"P$```@20``8````!(`
M#0``!```T!<````````2``T`JP0``"!&``"0````$@`-`/P#````D`$`````
M`"``%@"/`P``Y"L``!@````2``T`O0,``%2@`0``````$``7`!8$``"L(```
M_````!(`#0!@!```R$<``%@!```2``T`4P0``(PE``"<!0``$@`-``!?251-
M7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7U]G;6]N7W-T87)T7U\`7TE435]R
M96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN
M:70S`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?
M<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]S=E]S971P=FX`4$Q?9&]?
M=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!097)L7V-R;V%K
M7VUE;6]R>5]W<F%P`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R
M:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R
M=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO861E<@!P
M97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%]?97)R
M;F]?;&]C871I;VX`<F5A9`!O<&5N-C0`;'-E96LV-`!P=&AR96%D7V=E='-P
M96-I9FEC`&-L;W-E`&5X:70`<W1R;F-M<`!C;&]S961I<@!?7W-T86-K7V-H
M:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&%B;W)T`&UE;6-H<@!G971P
M:60`<W1R9'5P`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!?
M7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`
M;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN:P!S=')C
M:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?<W!R:6YT9E]C:&L`;65M
M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O
M;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]G=6%R9`!L:6)P97)L
M+G-O+C4N,S(`;&EB<'1H<F5A9"YS;RXP`&QI8F,N<V\N-@!L9"UL:6YU>"YS
M;RXS`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C`%]?8G-S7W-T
M87)T7U\`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``
M7V5D871A`%]?8G-S7V5N9%]?`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P
M87)?;6MT;7!D:7(`<VAA7W5P9&%T90!?7V1A=&%?<W1A<G0`7TE/7W-T9&EN
M7W5S960`<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!M
M>5]P87)?<&P`7V5N9`!?7V5N9%]?`'!A<E]I;FET7V5N=@!S:&%?9FEN86P`
M7U]B<W-?<W1A<G0`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI
M8G!A=&@`<&%R7V5N=E]C;&5A;@!S:&%?:6YI=`!84U]);G1E<FYA;'-?4$%2
M7T)/3U0`1TQ)0D-?,BXT``````````(``@`"``(``@`!``,``@`"``(`!``"
M``$``@`!``$``@`"``(``@`"``(``0`!``$``0`"``(``0`#``$``@`#``(`
M`@`!``$``@`"``(``0`"``$``P`"``$``0`"``(``0`!``$``0`"``$``@`"
M``$``@`!``(``@`!``$``0`"``(``@`"``,``@`"``,``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0````$``0!2`P``$````"`````4:6D-```$`,H$`````````0`!`#@#
M```0````(````!1I:0T```,`R@0````````!``$`2`,``!``````````%&EI
M#0```@#*!````````*R-`0`7````L(T!`!<```#$CP$`%P```.B/`0`7````
M\(\!`!<````$D`$`%P````R0`0`7````$)`!`!<````8D`$`%P```!R0`0`7
M````()`!`!<````DD`$`%P```"B0`0`7````,)`!`!<````TD`$`%P```#R0
M`0`7````R(\!`!4%``#,CP$`%0@``-"/`0`5#0``U(\!`!4/``#8CP$`%1D`
M`-R/`0`5&P``X(\!`!4>``#DCP$`%2<``.R/`0`5-```](\!`!4^``#XCP$`
M%4,``/R/`0`51```T(X!`!8#``#4C@$`%@0``-B.`0`6!0``W(X!`!8'``#@
MC@$`%@D``.2.`0`6"@``Z(X!`!8+``#LC@$`%@P``/".`0`6#@``](X!`!80
M``#XC@$`%A$``/R.`0`6$@```(\!`!83```$CP$`%A0```B/`0`6%0``#(\!
M`!86```0CP$`%A<``!2/`0`6&```&(\!`!8:```<CP$`%AP``""/`0`6'0``
M)(\!`!8?```HCP$`%B```"R/`0`6(0``,(\!`!8B```TCP$`%B,``#B/`0`6
M)```/(\!`!8E``!`CP$`%B8``$2/`0`6)P``2(\!`!8H``!,CP$`%BD``%"/
M`0`6*@``5(\!`!8K``!8CP$`%BP``%R/`0`6+0``8(\!`!8N``!DCP$`%B\`
M`&B/`0`6,```;(\!`!8Q``!PCP$`%C(``'2/`0`6,P``>(\!`!8U``!\CP$`
M%C8``("/`0`6-P``A(\!`!8X``"(CP$`%CD``(R/`0`6.@``D(\!`!8[``"4
MCP$`%CP``)B/`0`6/0``G(\!`!9```"@CP$`%D$``*2/`0`60@``J(\!`!9%
M``"LCP$`%D8``+"/`0`61P``M(\!`!9(``"XCP$`%DD``+R/`0`62@``P(\!
M`!9+```(0"WI?P$`ZPB`O>@$X"WE!."?Y0[@C^`(\+[EB'P!``#&C^(7RHSB
MB/R\Y0#&C^(7RHSB@/R\Y0#&C^(7RHSB>/R\Y0#&C^(7RHSB</R\Y0#&C^(7
MRHSB:/R\Y0#&C^(7RHSB8/R\Y0#&C^(7RHSB6/R\Y0#&C^(7RHSB4/R\Y0#&
MC^(7RHSB2/R\Y0#&C^(7RHSB0/R\Y0#&C^(7RHSB./R\Y0#&C^(7RHSB,/R\
MY0#&C^(7RHSB*/R\Y0#&C^(7RHSB(/R\Y0#&C^(7RHSB&/R\Y0#&C^(7RHSB
M$/R\Y0#&C^(7RHSB"/R\Y0#&C^(7RHSB`/R\Y0#&C^(7RHSB^/N\Y0#&C^(7
MRHSB\/N\Y0#&C^(7RHSBZ/N\Y0#&C^(7RHSBX/N\Y0#&C^(7RHSBV/N\Y0#&
MC^(7RHSBT/N\Y0#&C^(7RHSBR/N\Y0#&C^(7RHSBP/N\Y0#&C^(7RHSBN/N\
MY0#&C^(7RHSBL/N\Y0#&C^(7RHSBJ/N\Y0#&C^(7RHSBH/N\Y0#&C^(7RHSB
MF/N\Y0#&C^(7RHSBD/N\Y0#&C^(7RHSBB/N\Y0#&C^(7RHSB@/N\Y0#&C^(7
MRHSB>/N\Y0#&C^(7RHSB</N\Y0#&C^(7RHSB:/N\Y0#&C^(7RHSB8/N\Y0#&
MC^(7RHSB6/N\Y0#&C^(7RHSB4/N\Y0#&C^(7RHSB2/N\Y0#&C^(7RHSB0/N\
MY0#&C^(7RHSB./N\Y0#&C^(7RHSB,/N\Y0#&C^(7RHSB*/N\Y0#&C^(7RHSB
M(/N\Y0#&C^(7RHSB&/N\Y0#&C^(7RHSB$/N\Y0#&C^(7RHSB"/N\Y0#&C^(7
MRHSB`/N\Y0#&C^(7RHSB^/J\Y0#&C^(7RHSB\/J\Y0#&C^(7RHSBZ/J\Y0#&
MC^(7RHSBX/J\Y0#&C^(7RHSBV/J\Y0#&C^(7RHSBT/J\Y0#&C^(7RHSBR/J\
MY0#&C^(7RHSBP/J\Y0#&C^(7RHSBN/J\Y0#&C^(7RHSBL/J\Y0#&C^(7RHSB
MJ/J\Y0````!<PI_E7#*?Y7!`+>D,P(_@(-!-XA0`C>40$(WE#""-Y0,PG.<4
M`(WB$!"-X@P@C>(T0I_E`#"3Y1PPC>4`,*#CF?__ZR0BG^4$0(_@(#*?Y0(@
ME.<#`)3G`A"@X0`-`.L0,I_E`S"4YP!0T^4``%7C5P``"@`RG^4#0)3G``"4
MY=K__^O&(]#E`#"@X0(@@N/&(\/E``"4Y=3__^L40)WE!""$X@<!<N,#0(3B
MQC/0Y0$P@^/&,\#E8P``B@(!H.%;___KM"&?Y;3!G^40$)WE`B"/X``@DN4,
MP(_@%%"=Y0$`5>,`,*#A!`",Y0``D>4(((/EC"&?Y0``@^4"((_@#""#Y8`A
MG^4"((_@!""#Y4X``-H$`$'B#,"#X@4!@.`$X+'E!."LY0``4>'[__\:`Q"%
MX@``H.-049_E``"-Y0$!@^=($9_E!5"/X`0@H.$,`)7E`1"/X'3__^L`0%#B
M*```"BQ1G^488(WB!5"/X`P`E>4?___K'`&?Y080H.$``(_@J```ZP``4.,A
M```*"#&?Y0,PC^`,`)/E`/__ZUS__^OX()_EN#"?Y0(@C^`#,)+G`""3Y1PP
MG>4"(#/@`#"@XR,``!H$`*#A(-"-XG"`O>@0___KR""?Y0(@C^```%#C#`""
MY1L```KI_O_KA#"?Y0-`E.<``)3E>___ZWU7P.6<___J#`"5Y6+__^L`0*#A
MTO__Z@@`E>4``%#C`0``"E4(`.O8___J>`"?Y080H.$``(_@>P``ZP``4.,(
M`(7ET?__"O7__^I&___K!!"@X[;__^K:_O_K`0"@XPO__^N0>0$`#`$``%1Y
M`0`H`0``,`$``!@!```4`0``1'H!`$1Z`0`8-P``"#<``-1Y`0!("0``L'D!
M`%`T``"(>0$`\'<!`$!Y`0`X,P```+"@XP#@H.,$$)WD#2"@X00@+>4$`"WE
M**"?Y20PC^(#H(K@(,"?Y0S`FN<$P"WE&#"?Y0,PFN<4`)_E``":Y]O^_^LQ
M___KK'8!```!```D`0``+`$``!0PG^44()_E`S"/X`(@D^<``%+C'O\O`=7^
M_^J,=@$`(`$``"P`G^4L,)_E``"/X`,PC^```%/A(#"?Y0,PC^`>_R\!&""?
MY0(PD^<``%/C'O\O`1/_+^'D=P$`X'<!`%AV`0`(`0``.`"?Y3@PG^4``(_@
M`S"/X``P0^"C'Z#A0Q&!X"0PG^7!$+#A`S"/X![_+P$8()_E`C"3YP``4^,>
M_R\!$_\OX:!W`0"<=P$`"'8!`#0!``!,,)_E3""?Y0,PC^``,-/E`B"/X```
M4^,>_R\1.#"?Y1!`+>D#,)+G``!3XP(```HH,)_E`P"?YT[^_^O*___K'#"?
MY0$@H.,#,(_@`"##Y1"`O>A0=P$`S'4!``0!``#H=@$`$'<!`-#__^K,,)_E
M\$<MZ0"04.(#,(_@*P``"KP@G^4",)/G`("3Y0``6.,H```*`%#9Y0%PH.$`
M`%7C/0!5$P%0H!,`4*`#$0``&@!`F.4``%3C#```"@A@H.$$`*#A!2"@X0D0
MH.'(_O_K``!0XP(``!H%,-3G/0!3XPL```H$0+;E``!4X_/__QH$`*#A\(>]
MZ`E0H.$!,/7E``!3XST`4Q/[__\:"5!%X.;__^H(8$;@`5"%XD9AH.$%0(3@
M!`"@X0!@A^7PA[WH"4"@X>W__^H(0*#AZ___ZF1U`0`X`0``:"&?Y6@QG^4"
M((_@\$$MZ0,PDN=XT$WB`%!0X@`PD^5T,(WE`#"@XP(```H`,-7E``!3XPH`
M`!HX(9_E,#&?Y0(@C^`#,)+G`""3Y70PG>4"(#/@`#"@XT,``!IXT(WB\(&]
MZ#/^_^L`0%#B\?__"@1QG^4'<(_@!`"@X7[^_^L``%#C*@``"A,PT.438(#B
M+@!3XP(``!H!,-;E``!3X_3__PH3,-#E+@!3XR4```H%`*#A-_[_ZP"`H.$&
M`*#A-/[_ZP``B.`"`(#B'_[_ZP<PH.$`(.#C`1"@XP1@C>4`4(WE`&"@X3G^
M_^L(((WB!A"@X0,`H.-H_O_K`0!PXP8`H.$#```*&#"=Y0\Z`^(!"5/C$@``
M"N[]_^L&`*#AT?W_ZP0`H.%3_O_K``!0X]3__QH$`*#A9_[_ZP4`H.'/_?_K
MN___Z@$PUN4N`%/CUO__&@(PUN4``%/CQ?__"M+__^JE___KZ___ZM/]_^N,
M=`$`#`$``%1T`0"0+P``F,"?Y9@PG^4,P(_@$$`MZ7#03>(#,)SG`!"@X0!`
MH.$-(*#A`P"@XP`PD^5L,(WE`#"@XT7^_^L``%#C``"@$P0``!H0,)WE#SH#
MX@H*4^,!"5,3"@``"D@@G^5`,)_E`B"/X`,PDN<`()/E;#"=Y0(@,^``,*#C
M!P``&G#0C>(0@+WH`A"@XP0`H.$1_O_K$`]OX:`"H.'N___JI_W_ZPQS`0`,
M`0``M'(!`/!#+>D!8*#A#!&?Y0PQG^4!VDWB#-!-X@$0C^`#,)'G`$"@X0$*
MC>($`(#B`#"3Y0`P@.4`,*#CY`"?Y01PC>+@()_E``"/X`<0H.&B_?_KU("?
MY0B`C^``P%#B%@``V@A0C>(!D$SB"5"%X`0P5>4``%/C)0``&@``6>,.```*
M"2"@X2\0H.,'`*#AX_W_ZP``4.,(```*D#"?Y0,PF.<``)/E!/[_ZPDPH.$'
M(*#A!!"@X>C]_^L&``#J;#"?Y0,PF.<``)/E^_W_ZP8@H.$$$*#A??W_ZU0@
MG^4\,)_E`B"/X`$:C>(#,)+G!!"!X@`@D^4`,)'E`B`SX``PH.,$```:`=J-
MX@S0C>+P@[WH#)"@X=G__^I=_?_K4'(!``P!``"<+0``_P\``!1R`0`4`0``
MB'$!`/!'+>D`,-'E$"*?Y3T`4^,,,I_E`B"/X`%`H.$#,)+G`4"!`@C03>(`
M4*#A!`"@X0`PD^4$,(WE`#"@XWS]_^L-$*#AW(&?Y0B`C^``8*#A!0"@X=G^
M_^L`D%#B0```"G/]_^L``%;A-P``FK@QG^4`<)WE`X"8YP=QH.$`,-7E``!3
MXST`4Q,!,*`3`#"@`P4```H%,*#A`2#SY0``4N,]`%(3^___&@4P0^`"`(;B
M`P"`X`!@F.5+_?_K``!0XP<`AN<5```*`""8Y04`H.$!,-#D!Q"2YP``4^,]
M`%,3`##!Y08```H!(('B`3#0Y`(0H.$]`%/C``!3$P$PPN3Y__\:/3"@XP$@
MH.$`,,'E`3#4Y`$PXN4``%/C^___&@@AG^7X,)_E`B"/X`,PDN<`()/E!#"=
MY0(@,^``,*#C-0``&@C0C>+PA[WH`9!)X@$PU.0!,.GE``!3X_O__QKN___J
MP#"?Y0.`F.<`<)CE`#"7Y0``4^,D```*!S"@X00@L^4)$*#A``!2XP&0B>+Z
M__\:`Q"!X@$1H.&0,)_E`S"/X``@D^4``%+C#P``&@$@H.,!`*#A`""#Y0K]
M_^L`H%#BU?__"@<0H.$)<:#A!R"@X<C\_^L`H(CE`#"@XP"0C>4!D(GB"3&*
MYZ+__^H'`*#AX?S_ZP``4.,`H*#A``"(Y<7__PH)<:#A\O__Z@.0H.$($*#C
MW___ZL[\_^L<<0$`#`$``.AP`0`X`0``"'`!`!!Q`0`P0"WI;$"?Y6PPG^4$
M0(_@`U"4YPS03>(``)7E2OW_ZP``E>5(_?_K4""?Y5`PG^50$)_E`B"4YP,P
MC^`!$(_@`OW_ZP``E>4__?_K.#"?Y3@@G^4X$)_E`S"/X`#`H.,"((_@`1"/
MX`@0C>@,_?_K#-"-XC"`O>CL;@$`%`$``!`!``#D:```1"H``!`M``"P%0``
M."H``!!`+>DP0)_E,#"?Y01`C^`#,)3G``"3Y27]_^L@()_E(#"?Y2`0G^4"
M()3G`S"/X!!`O>@!$(_@WOS_ZE1N`0`4`0``$`$``%AH``"T*0``W""?Y7!`
M+>G8,)_E`MI-XAC03>("((_@`S"2YP(:C>(4$('B`#"3Y0`P@>4`,*#CL?S_
MZ[`0G^6P,)_E#$"-X@$0C^`!:HWBI""?Y0,PC^`08(;B`P"-Z`$0H.,$`*#A
MNOS_ZP0`H.$!*J#C!A"@X8/\_^L`0%#B`%"@LP@``+H!`(3BD/S_ZP!04.($
M```*!""@X080H.%5_/_K`#"@XP0PQ>=,()_E.#"?Y0(@C^`"&HWB`S"2YQ00
M@>(`()/E`#"1Y0(@,^``,*#C`P``&@4`H.$"VHWB&-"-XG"`O>A5_/_K_&T!
M``P!``"8*0``@"D```$0``!D;0$`O___ZE@BG^7P3RWI5#*?Y4+=3>(,T$WB
M`B"/X`!@H.%$`I_E`S"2YT+-C>(8@(WB`5"@X0``C^`($*#A!,",X@`PD^4`
M,(SE`#"@X]3]_^LO$*#C`$"@X08`H.%S_/_K``!0XQ(```H``I_E!A"@X0``
MC^#:_O_K!@"@X?`AG^7@,9_E`B"/X$(=C>(#,)+G!!"!X@`@D^4`,)'E`B`S
MX``PH.-M```:0MV-X@S0C>+PC[WH!@"@X5;\_^NT$9_E`1"/X`"0H.$%`*#A
MA_S_ZP"P4.+C__\*G#&?Y0MPH.$#,(_@%#"-Y9`QG^60H9_E`S"/X!`PC>4`
M,-?E"J"/X```4^,U```*``!4XP0```H'$*#A!`"@X>'[_^L``%#C.0``"@<`
MH.$Z_/_K`3!`X@,@U^<#,(?@+P!2XP4``!H`P*#C`,##Y0$@<^4!`$#B+P!2
MX_K__PH!,(GB`#"#X`$*4^.___^J&"&?Y810C>("((_@"C"@X0$0H.-$`(WI
M!0"@X0$JH.,`<(WE,/S_ZP@@H.$%$*#A`P"@XU_\_^L``%#C`P``&B@PG>4/
M.@/B`@E3XQH```K,$)_E``"@XP$0C^!)_/_K`'"@X0``5^.D__\*`##7Y0``
M4^/)__\:``!4XQH```H`,-3E+@!3XP(```H4<)WE`0"@X]7__^H!,-3E``!3
MX_G__QI\$)_E``"@XP$0C^`T_/_K`'"@X>G__^H!$*#C!0"@X2G\_^L``%#C
MW___&E0`G^4%$*#A``"/X&;^_^L%`*#AN/O_ZXG__^H0<)WE`0"@X[W__^JV
M^__K_&P!``P!``"P*```@"@``)!L`0!`*````"@``/`G```(*```G"<``$`G
M``#L)@``L"8````PT.4``%/C'O\O`0$@@.(O`%/C`@"@`0$PTN0``%/C^O__
M&A[_+^$00"WI`$!0XBX```H`,-3E``!3XRL```K.^__K`3!`X@,PA.`#`%3A
M*@``*@,@H.$"``#J!`!2X0(PH.$E```*`C"@X0$04N0O`%'C^/__"@,`5.$?
M```J`3!#X@,`5.$>```*`"#3Y2\`4N/Y__\:`3!#X@,``.H`$-/E`3!#XB\`
M4>,"```:`P!4X0,@H.'X__\Z!"!"X`(P@N(!"E/C%0``BF@`G^4$$*#A``"/
MX`!`H.$!.J#C`2""XFG[_^L$`*#A$("]Z$@`G^400+WH``"/X&;[_^H#`%3A
MX___&@`PU.4O`%/C!0``"B@`G^400+WH``"/X%W[_^H``*#C$("]Z!0`G^40
M0+WH``"/X%?[_^HX:P$`4"4``%@E```4)0``("6?Y2#%G^4@-9_E`B"/X'!`
M+>D#,)+G#,"/X##03>(,P(SB`#"3Y2PPC>4`,*#C#P"\Z`C@C>(/`*[H#P"\
MZ.QDG^7L5)_E#P"NZ`9@C^``,)SE!$"-X@50C^"P,,[A!!"@X08`H.'4_/_K
M``!0XPX```K`-)_E!`"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$
M,(/B!""3Y00@@^0``%+C^___&NO__^J(9)_E!F"/X`00H.$&`*#AOOS_ZP``
M4.,.```*:#2?Y00`G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#
MX@0@D^4$((/D``!2X_O__QKK___J-&2?Y09@C^`$$*#A!@"@X:C\_^L``%#C
M#@``"A`TG^4$`)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($
M()/E!""#Y```4N/[__\:Z___ZN!CG^4&8(_@!!"@X08`H.&2_/_K``!0XPX`
M``JX,Y_E!`"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3
MY00@@^0``%+C^___&NO__^J,8Y_E!F"/X`00H.$&`*#A?/S_ZP``4.,.```*
M8#.?Y00`G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@D^4$
M((/D``!2X_O__QKK___J.&.?Y09@C^`$$*#A!@"@X6;\_^L``%#C#@``"@@S
MG^4$`)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E!""#
MY```4N/[__\:Z___ZN1BG^4&8(_@!!"@X08`H.%0_/_K``!0XPX```JP,I_E
M!`"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@@^0`
M`%+C^___&NO__^J08I_E!F"/X`00H.$&`*#A.OS_ZP``4.,.```*6#*?Y00`
MG>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@D^4$((/D``!2
MX_O__QKK___J/&*?Y09@C^`$$*#A!@"@X23\_^L``%#C#@``"@`RG^4$`)WE
M`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E!""#Y```4N/[
M__\:Z___ZNAAG^4&8(_@!!"@X08`H.$._/_K``!0XPX```JH,9_E!`"=Y0,P
ME><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@@^0``%+C^___
M&NO__^J489_E!F"/X`00H.$&`*#A^/O_ZP``4.,.```*4#&?Y00`G>4#,)7G
M`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@D^4$((/D``!2X_O__QKK
M___J0`&?Y000H.$``(_@X_O_ZP`04.("```*+`&?Y0``C^#N_/_K)`&?Y000
MH.$``(_@VOO_ZP`04.("```*$`&?Y0``C^#E_/_K"`&?Y000H.$``(_@T?O_
MZP`04.(2```*]`"?Y0``C^#<_/_K[!"?Y>P`G^4!$(_@``"/X-?\_^O@()_E
MA#"?Y0(@C^`#,)+G`""3Y2PPG>4"(#/@`#"@XQ<``!HPT(WB<("]Z+@`G^4$
M$*#A``"/X+C[_^L`$%#B`P``"J0`G^4``(_@P_S_Z^7__^J8$)_E"B"@XP$0
MC^`9`(WBC_K_ZP``4./>__\:@`"?Y2,0C>(``(_@M_S_Z]G__^H,^O_K)&D!
M`#QC```,`0``X"0``-AH`0`X`0``A"0``#0D``#H(P``F",``%`C``"4(@``
MK"(``&`B```4(@``0"$``&PA``!`(0``7"$``%PA``!8(0``?"```&0A``"\
M(```B&0!``0A``"((```\"```%@@``"<,)_EG!"?Y9P@G^4#,(_@!.`MY0$0
MC^```)/E`B"1YPS03>(!`'#C`""2Y00@C>4`(*#C"@``"G`@G^5H,)_E`B"/
MX`,PDN<`()/E!#"=Y0(@,^``,*#C$```&@S0C>($\)WD2`"?Y0T0H.$``(_@
M:_O_ZP``4.,$```*``#0Y3``4.,``%`3`0"@$P``H`,@,)_E`S"/X```@^7E
M___JQOG_Z\QD`0"`8P$`#`$``%1C`0!H'P``1&0!`!!`+>FC^?_KG/G_ZP``
M4.,``)`5$("]Z#PAG^7P0"WI.#&?Y3AAG^4"((_@'-!-X@,PDN<&8(_@`%"@
MX1`0C>(&`*#A`#"3Y10PC>4`,*#C1/O_ZP!`4.("```*`##4Y0``4^,.```:
M^""?Y>PPG^4"((_@`S"2YP`@D^44,)WE`B`SX``PH.,R```:V`"?Y040H.$`
M`(_@'-"-XO!`O>A`_/_J!1"@X6OY_^L``%#C"@``"K0@G^6@,)_E`B"/X`,P
MDN<`()/E%#"=Y0(@,^``,*#C'P``&AS0C>+P@+WH!0"@X;SY_^L`<*#A!`"@
MX;GY_^L``(?@`@"`XJ3Y_^ML()_E;#"?Y0(@C^`#,(_@`1"@XPA`C>4$((WE
M`%"-Y0`@X.,`0*#ANOG_ZT@@G^4H,)_E`B"/X`,PDN<`()/E%#"=Y0(@,^``
M,*#C!!"@`08`H`'/__\*:?G_Z[!B`0`,`0``<!\``&AB`0`0'P``'&(!`+P=
M``"\'0``I&$!`-P7G^7P3RWIV">?Y8'<3>($T$WB`1"/X,PWG^4<`(WE`@F-
MX@(@D><#,(_@`""2Y?P@@.4`(*#C_`"`X@<`D^D!?(WB=(!'XA#@@^(H4(/B
M!P"(Z`\`ONA<P$?B#P"LZ`,`GNAH0$?B`P",Z`<`E>@'`(3H=`>?Y>!@1^(&
M$*#A``"/X-?Z_^MDIY_E"J"/X`!`4.("```*`##4Y0``4^,B`0`:&_G_ZQ3Y
M_^L`@%#B^0``"@!0F.4``%7C]0``"@4`H.%D^?_K@`"@X0$`@.)/^?_K`"#5
MY0``4N,`@*#A#```"@RWG^4(0*#A"["/X`0`H.$`((WE"S"@X0`@X.,!$*#C
M8_G_ZP$@]>4"0(3B``!2X_7__QK<!I_E6%!'X@``C^`"``#J!`"5Y```4.,-
M```*!A"@X:KZ_^L`0%#B^/__"@`PU.4``%/C]?__"CO[_^L``%#C\O__"@0`
MH.$$^?_K`%!0XA,``!H`D*#C=+!'X@DAA^!T0!+E``!4XPP```H!4(GB!5&+
MX``@U.4``%+C!P``"@0`H.$H^__K`9")X@``4.-$```:!$"5Y```5./T__\:
M`%"@XP4`H.$E^?_K`$"@X0@`H.$B^?_K`$"$X`%+A.($0(3B!`"@X0OY_^L4
M-I_E`"#@XP,PC^`(,(WE"#:?Y0$0H.,#,(_@!#"-Y?PUG^4,@(WE`S"/X`!0
MC>4`@*#A'OG_ZP<=H.,(`*#A)/G_ZP$`<.,#```:%?G_ZP`0D.41`%'CK@``
M&@8@H.$($*#A`P"@XU#Y_^L`4%#B'@``"JPEG^4<,)WE`A":YZ0EG^4``)'E
M`#"3Y0(@C^`!$*#C`("-Y1WY_^L`H*#CB"6?Y5@UG^4"((_@`AF-X@,PDN?\
M$('B`""3Y0`PD>4"(#/@`#"@XTL!`!H*`*#A@=R-X@30C>+PC[WH!`"@X:OX
M_^L`4%#BJ/__"KG__^K0,!?E#SH#X@$)4^/<__\:R+`7Y8KX_^L``%OAV/__
M&M`P%^6#.Z#AHSN@X0<-4^/3__\:!`"@X<#X_^L&$*#A`*"@X?@$G^4``(_@
M,/K_ZP``4..8```*'#"=Y0!`D^6/^/_K`!"@X00`H.%`_/_K`+!0XI````H+
M`*#AP?C_ZP,`4.,`0*#A#```FK04G^4$`$#B``"+X`$0C^!<^/_K``!0XP4`
M`!H$`%3CX```"@1`B^`%,%3E+P!3X]P```J$1)_E!$"/X``PE.4!`'/C?```
M"@``4^.)```*;!2?Y6P$G^4!$(_@``"/X!C[_^N>^/_K7#2?Y5R4G^4#,(_@
M##"-Y50TG^54=)_E`S"/X`0PC>5,-)_E3&2?Y0,PC^``(.#C`1"@XP"`C>4)
MD(_@!W"/X`9@C^`(`(WE"@"@X9_X_^L/``#JFOC_ZP`PD.41`%/C$0``&H3X
M_^L!4(7B"3"@X00@H.$!$*#C$'"-Y0Q0C>4`@(WE`,"@X4`0C>D*`*#ACOC_
MZP<=H.,*`*#AE/C_ZP$`<.,`0*#AZ?__"@@`H.$L^/_KP`.?Y0H0H.$``(_@
MYOK_ZPH`H.&`_O_K>O__Z@6`H.%H0$?B"#&'X&@`$^4``%#C,```"@&PB.(+
M483@`P``Z@0`E>0``%#C*@``"@&PB^(&$*#AQ/G_ZPN`H.$`,%#B]O__"@`P
MT^4``%/C\___"B'X_^L`4%#B\?[_&NC__^H((Y_E'#"=Y0(`FN<X(Y_E`#"3
MY0``D.4"((_@!!"-Y0"`C>4!$*#C<_C_ZP"@H.-4___J6/[_ZQ`CG^6H,I_E
M`B"/X`(9C>(#,)+G_!"!X@`@D^4`,)'E`B`SX``PH..?```:!`"@X8'<C>($
MT(WB\$^]Z`#X_^H-`*#C)?C_Z\Q2G^53(*#C!5"/X`"`H.'4_O_J'#"=Y0"P
MD^5K___JL`*?Y080H.$``(_@COG_ZP``4.-D```*`##0Y0``4^,P`%,3`3"@
M$P`PH`,!,*`3`#"$%0`PA`5U__\:"P"@X0`0H.,(^/_K`$!0XG#__PH"4*#C
M`##@XQ$@X.,$8$?B`%"-Y??W_^L&(*#C!A"@X00`H.&]]__K!#!7Y0``4^,"
M```:`S!7Y4,`4^-(```*`#"@XP`@H.,`,(WE!`"@X0`PH./G]__KG`0`ZP!0
MH.$"``#J!A"@X04`H.&[!`#K`BF@XP80H.$$`*#AI_?_ZP`@4.+V___*!`"@
MX41`1^)!^/_K!1"@X00`H.'U!`#KQ)&?Y3!@1^()D(_@!E"@X0$0U.0%`*#A
M`!"-Y0DPH.$`(.#C`1"@X_?W_^L$`%;A`E"%XO7__QJ0,9_E`""@XP,PC^`$
M,(WE"&"-Y0"`C>4(($?E>"&?Y7@QG^4"((_@#""-Y0,PC^``(.#C`1"@XPH`
MH.'D]__K6O__ZAPPG>4$0)/E``!4XQ[__PH$`*#ASO?_ZP,`4.,:__^:.!&?
MY00`0.(``(3@`1"/X&KW_^L``%#C!+"@`1+__^H``(3EH?__Z@(P5^5!`%/C
ML___&@$P5^5#`%/CL/__&@`PU^5(`%/CK?__&@$PU^5%`%/CJO__&@`PX.,Y
M(.#C!`"@X0!0C>63]__K!A"@X2D@H.,$`*#A6??_Z\`PG^7`$)_E`S"/X`PP
MC>6X,)_E`1"/X`00C>4#,(_@`"#@XP$0H.,*`*#A"&"-Y0"`C>6N]__K)/__
MZF?W_^M$80$`#`$``'1B`0"H'```S&`!`%`=``#$'```9!P``%0;```X'```
M'`$``"0<``#,7@$`S!L``(0;```$7P$`:!H``-P9``#X&P``(!L``'`9``#$
M&P``(!L``$@9``"D&```1!D``!Q<`0"P&```]!<``*@7``"$%@``X!@``!`8
M``#$%P``'!@``)@5``!`%P``=`*?Y702G^4``(_@\$`MZ0$0D.=H,I_E#-!-
MXF0BG^4#,(_@`!"1Y000C>4`$*#C`D"3YPU@H.$``)3EO/?_ZP!0H.$``)3E
MN??_ZV@@U>4&$*#A`#"@X2P"G^5I(,/E``"/X,'X_^L``%#C`@``"@`PT.4Q
M`%/C8P``"LO[_^L``)3EJO?_ZP`2G^4#,*#C`2"@XP$0C^!%]__K`%!0X@L`
M``H``)3EH??_ZQ`PE>7<(9_E`!"3Y0(@C^`A]__K$#"5Y0`PD^4(,)/E`043
MXUH``!H``)3EE??_Z[01G^4#,*#C`2"@XP$0C^`P]__K`%!0X@L```J<`9_E
M!A"@X0``C^"9^/_K`'!0X@``E.5!```*AO?_ZQ`PE>4'(*#A`!"3Y0?W_^L`
M`)3E@/?_ZP!0H.$``)3E???_ZUP1G^4!(*#C`1"/X"[W_^M0(9_E`B"/X``0
MH.$%`*#A^?;_ZP``E.5R]__K`""@XP80H.$P49_E!5"/X``PH.$H`9_E:2##
MY0``C^!X^/_K``!0XP!`H.$(`(7E$@``"@<=H.,$`*#A)O?_ZP$@@.(1`%#C
M`0!2$P`PH.$G``"*[""?Y;@PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,=
M```:#-"-XO"`O>@$`)7E9?W_ZP``4.,`0*#A"`"%Y>;__QJL`)_E``"/X`?W
M_^L!,-#E``!3XYG__PJ7___J1/?_ZY`PG^40()7E`S"/X`0PD^4``)+E`!"3
MY0[Y_^NY___J``"4Y3KW_^L0,)7E`!"3Y03W_^N>___JJ_;_ZU@@G^58`)_E
M`B"/X`0@DN4``(_@`!"2Y00@H.'K]O_KV%@!``P!``#`6`$`%`$``*04```H
M%@``"!8``.`5``"\$P``B!4``)05``#L6`$`+!,``!Q7`0#H%```.%@!`/Q7
M`0"D%```3"&?Y4PQG^4"((_@\$`MZ0,PDN<,T$WB`#"3Y00PC>4`,*#C`'"@
MX>;Z_^L`,-#E`$"@X0``4^,%```*`2"`XB\`4^,"0*`!`3#2Y```4^/Z__\:
M`&&?Y0!05^(&8(_@`#"6Y0%0H!,!`'/C)@``"@``4^,`4*`#`5`%$@``5>,*
M```:U""?Y<@PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,I```:#-"-XO"`
MO>@`,-?E``!3X_'__PJ@$)_E!""@XP$0C^`$`*#AV/;_ZP``4./J__\:B""?
MY70PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,4```:!P"@X0S0C>+P0+WH
M'OC_ZE@`G^4-$*#A``"/X./W_^L``%#C``"&!=;__PH`,-#E``!3XS``4Q,`
M,*`#`3"@$P`PA@7/__\*`3"@XP`PAN7*___J//;_ZQ16`0`,`0``!%<!`)!5
M`0!0$@``/%4!`$@1``#L*Y_E[#N?Y0(@C^#P3RWIH]]-X@,PDN<-X*#A0,"`
MXH!@@.(.$*#A`#"3Y80RC>4`,*#C`%"@XP1`'.4(<!SE)#2@X6<H)^#_/`/B
M)#R#X2(DH.$$A*#A!#R#X?\LPN/_2`CB",",XF<D(N`$,(/A!@!<X20`@>@(
M,('E#%"!Y1`0@>+K__\:",!-XG[OCN(`,*#C#$"@X7`@G.5(D)SE=!"4Y0A@
MO.5,@)3E&'"4Y1Q0E.4)("+@!$"<Y0@0(>`'("+@!B`BX`40(>`$$"'@HD^@
MX8%`A.$"()+@!"""X0X`7.'P*,SAZ?__&@@KG^4`$)WE`$"0Y2!PD.4$P)#E
M`A"1X`<0D>"D?:#A$."0Y1A0D.6,<H?A"&"0Y81RA^$,D)#E`7"7X`40+N`F
M@:#A!A`!X`40(>`)CXCA`7"7X`:/B.$($)WE))&@X0R?B>$(P"[@`A"1X`3`
M#.`.P"S@!1"1X`2?B>$,$)'@$,"=Y0F@*.`"P)S@!Z`*X`B@*N`.P)S@YQV!
MX`K`G.#AK8S@&,"=Y:BPG>4"P)S@","<X&>!*>`!@`C@"8`HX`B`G.`@P)WE
M81&@X0+`G.`)P)S@9Y$AX`J0">!GD2G@ZHV(X`G`G.#HG8S@*,"=Y0+`G.!G
MP8S@:G$AX`AP!^`!<"?@!\"<X#!PG>5H@:#A`G"7X`$0E^!J<2C@"7`'X&IQ
M)^#IS8S@!Q"1X.Q]@>`X$)WE`A"1X&H1@>!IH2C@#*`*X`B@*N`*$)'@0*"=
MY6S!H.$"H)K@"(":X&FA+.`'H`K@::$JX.<=@>`*@)C@X:V(X$B`G>4"@)C@
M:8&(X&>1+.`!D`G@#)`IX`F`F.!0D)WE81&@X0*0F>`,P)G@9Y$AX`J0">!G
MD2G@ZHV(X`G`G.#HG8S@6,"=Y0+`G.!GP8S@:G$AX`AP!^`!<"?@!\"<X&!P
MG>5H@:#A`G"7X`$0E^!J<2C@"7`'X&IQ)^#IS8S@!Q"1X.Q]@>!H$)WE`A"1
MX&H1@>!IH2C@#*`*X`B@*N`*$)'@<*"=Y6S!H.$"H)K@"(":X&FA+.`'H`K@
M::$JX.<=@>`*@)C@X:V(X'B`G>4"@)C@:8&(X&>1+.`!D`G@#)`IX`F0F."`
M@)WE81&@X0*`F.`,P)C@9X$AX`J`".!G@2C@ZIV)X`C`G.#IC8S@B,"=Y0+`
MG.!GP8S@:G$AX`EP!^`!<"?@!\"<X)!PG>5ID:#A`G"7X`$0E^!J<2G@"'`'
MX&IQ)^#HS8S@!Q"1X.Q]@>"8$)WE`B"1X&@1*>`,$`'@"1`AX&HA@N`!()+@
MYQV"X*"@G>4@*)_E;,&@X0*@FN`)H)K@:)$LX`>0*>`)D)K@`J";X&BABN"P
ML)WE9X$LX`&`*.#AG8G@"(":X&$1H.$"H)O@#*":X+BPG>5GP2'@"<`LX.F-
MB.`,P)K@`K";X.BMC.!G<8O@:<$AX,"PG>4(P"S@#,"7X&B!H.$"<)O@`7"7
MX,BPG>5I$2C@"A`AX.K-C.`!$)?@`G";X&EQA^#0L)WE[)V!X&H1*.`,$"'@
M`1"7X&S!H.$"L)O@"(";X&IQ+.#8L)WE"7`GX.D=@>`'<)C@`H";X&J!B.#@
ML)WEX:V'X&EQ+.`!<"?@!W"8X&$1H.$"@)O@#("8X.BPG>5IP2'@"L`LX.I]
MA^`,P)C@`H";X&F!B.#PL)WEYYV,X&K!(>`'P"S@#,"8X&=QH.$"@)O@`8"8
MX/BPG>5J$2?@"1`AX.G-C.`!$)C@`H";X&J!B.#LK8'@:1$GX`P0(>`!$)C@
M`(&=Y6S!H.$"@)C@"+&=Y0>`F.!I<2S@"G`GX.H=@>`'<)C@`H";X&F!B.`0
ML9WEX9V'X&IQ+.`!<"?@!W"8X&$1H.$"L)O@#,";X&J!(>`8L9WE"8`HX`B`
MG.`"P)O@Z7V'X&K!C.!IH2'@!Z`JX`J@G.`@P9WE9[&@X0+`G.#GC8C@`<"<
MX&D1*^`($"'@`1"<X"C!G>7HK8K@`L"<X.I]@>!IP8S@:!$KX#"1G>4*$"'@
M`<"<X&H1H.$"D)G@"Y"9X&BA(>`XL9WE!Z`JX.?-C.`*H)G@`I";X&>Q(>#D
M)9_E[*V*X&B1B>`,L"O@;(&@X4#!G>4+L)G@9Y&(X0+`G.`!P)S@"I`)X.H=
MB^!GL0C@"Y")X0F0G.!(P9WE:K$(X`+`G.!G<8S@:L&(X0'`#.`+P(SA!\"<
MX%!QG>7AG8G@`G"7X&$1H.$(<)?@:H&!X6JQ`>`)@`C@"X"(X0>`F.!8<9WE
MZ<V,X`)PE^!JH8?@:7&!X6FQ`>`,<`?@"W"'X0J@E^!@<9WE[(V(X`)PE^!L
MP:#A`7"7X.@=BN!IH8SA:;$,X`B@"N`+H(KA!W":X&BAG>5HL0S@`J":X&FA
MBN!HD8SA`9`)X`N0B>$*H)G@<)&=Y>%]A^`"D)G@81&@X0R0F>#GS8K@:*&!
MX6BQ`>`'H`K@"Z"*X0F0FN!XH9WE9[$!X`*@FN!HH8K@[(V)X&>1@>$,D`G@
M"Y")X0J@F>"`D9WE;,&@X0*0F>`!D)G@Z!V*X&>AC.%GL0S@"*`*X`N@BN$)
MD)K@B*&=Y6BQ#.`"H)K@9Z&*X.%]B>!HD8SA`9`)X`N0B>$*H)G@D)&=Y6$1
MH.$"D)G@#)"9X.?-BN!HH8'A:+$!X`>@"N`+H(KA"9":X)BAG>5GL0'@`J":
MX&BABN#LC8G@9Y&!X0R0">`+D(GA"J"9X*"1G>5LP:#A`I"9X`&0F>#H'8K@
M9Z&,X6>Q#.`(H`K@"Z"*X0F0FN"HH9WE:+$,X`*@FN!GH8K@X7V)X&B1C.$!
MD`G@"Y")X0J@F>"PD9WE81&@X0*0F>`,D)G@Y\V*X&BA@>%HL0'@!Z`*X`N@
MBN$)D)K@N*&=Y6>Q`>`"H)K@:*&*X.R-B>!GD8'A#)`)X`N0B>$*H)G@P)&=
MY6S!H.$"D)G@`9"9X.@=BN!GH8SA9[$,X`B@"N`+H(KA!#"`Y0F0FN#(H9WE
M:+$,X`*@FN!GH8K@:'&,X0%P!^`+<(?A"G"7X-"AG>7AG8G@`J":X&$1H.$,
MP)K@:*&!X6BQ`>`)H`K@"Z"*X0S`FN#8H9WEZ7V'X`*@FN!HH8K@YXV,X&G!
M@>%IL0'@!\`,X`O`C.'<(I_E"L"<X."AG>5G<:#A`J":X`&@FN#HL9WE:1$G
MX`@0(>#HS8S@`1":X`*PF^#LK8'@:9&+X&@1)^#PL9WE#!`AX`$0F>!LP:#A
M`I";X`>0F>#XL9WE:'$LX`IP)^#J'8'@!W"9X`*PF^#AG8?@:(&+X&IQ+.``
MLIWE`7`GX`=PF.!A$:#A`H";X`R`F.`(LIWE:L$AX`G`+.#I?8?@#,"8X`*`
MF^!J@8C@$+*=Y>>MC.!IP2'@!\`LX`S`F.!G<:#A`H";X`&`F.`8LIWE:1$G
MX`H0(>#JS8S@`1"8X`*`F^!I@8C@(+*=Y>R=@>!J$2?@#!`AX`$0F.!LP:#A
M`H";X`>`F.`HLIWE:G$LX`EP)^#I'8'@!W"8X`*`F^!J@8C@,+*=Y>&MA^!I
M<2S@`7`GX`=PF.!A$:#A`H";X`R`F.`XLIWE:<$AX`K`+.#J?8?@#,"8X`*`
MF^!I@8C@0+*=Y>>=C.!JP2'@!\`LX`S`F.!G<:#A`H";X`&`F.!(LIWE:A$G
MX`D0(>#IS8S@`1"8X`*`F^!J@8C@4+*=Y>RM@>!I$2?@#!`AX`$0F.!LP:#A
M`H";X`>`F.!8LIWE:7$LX`IP)^#J'8'@!W"8X`*`F^!I@8C@8+*=Y>&=A^!J
M<2S@`7`GX`=PF.!A$:#A`H";X`R`F.!JP2'@"<`LX.E]A^`,P)C@Y\V,X&BR
MG>5L487@`H";X!A0@.5I42'@:H&(X`=0)>`%4)C@[%V%X'"BG>5G<:#A9>&.
MX`*@FN!I@2?@$."`Y7CBG>4,@"C@`1":X`@0D>`"()[@!""2X&S!)^`%P"S@
M:2&"X`P@DN#E'8'@(,"0Y>$M@N``((#E!A"1X%P@G^4,<)?@##"`Y10P@.4<
M,(#E"!"`Y2!P@.4D,(#E*#"?Y0(@C^`#,)+G`""3Y80RG>4"(#/@`#"@XP$`
M`!JCWXWB\(^]Z#CS_^ND5`$`#`$``)EY@EJAZ]ENW+P;C];!8LK@2`$`<$`M
MZ8``H.-2\__K5%"/XM!`Q>$`(*#C\$#`X4Q0C^+00,7A>""`Y?A`P.%$4(_B
MT$#%X?!!P.%`4(_BT$#%X?A!P.$\4(_BT$#%X?!"P.$`0*#C`%"@X_A"P.'P
M0\#A<("]Z```H.$!(T5G`````(FKS>\`````_MRZF`````!V5#(0`````/#A
MTL,`````\$<MZ2@PD.4"8*#AAL&#X"P@D.4#`%SA`#"@XP(@T^``4*#A,""0
MY0%`H.$T$)#EQ@^@X0$``"H!()+B`!"AXBPPA>6F/J#A@#&#X0(PD^"@'J'@
M>`"5Y3B`A>(``%#C*,"%Y3`PA>4T$(7E%@``&C\`5N,E``#:0&!&XB:3H.$!
M<(GB!W.$X`00H.%`(*#C"`"@X=7R_^M`0(3B!0"@X:[\_^L'`%3A]O__&@F=
M:>`)8X;@!B"@X0<0H.$(`*#ARO+_ZWA@A>7PA[WH0'!@X@8`5^$&<*"A``"(
MX`<@H.$$$*#AP?+_ZW@PE>4#,(?@0`!3XW@PA>7PA[T8!0"@X0=@1N`'0(3@
ME/S_Z]?__^H$<*#AYO__ZO!!+>DH,)'E`4"@X6,H(^`P$)'E(B2@X?\LPN-C
M="+@82@AX*,QH.$B)*#A/S`#XO\LPN-A9"+@`2"#XCB`A.)_$.#C.`!2XP!0
MH.$#$,CG`@"(X#L``-I`(&+B`!"@X__R_^L$`*#A=OS_ZP@`H.$X(*#C`!"@
MX_GR_^L$`*#A\&?$X6_\_^L#,-3E`##%Y;(PU.$!,,7E`#"4Y00`H.$C-*#A
M`C#%Y0`PE.4#,,7E"S#4Y00PQ>6Z,-3A!3#%Y0@PE.4C-*#A!C#%Y0@PE.4'
M,,7E$S#4Y0@PQ>6R,=3A"3#%Y1`PE.4C-*#A"C#%Y1`PE.4+,,7E&S#4Y0PP
MQ>6Z,=3A#3#%Y1@PE.4C-*#A#C#%Y1@PE.4/,,7E(S#4Y1`PQ>6R,M3A$3#%
MY2`PE.4C-*#A$C#%Y2`PE.43,,7E\$&]Z&#R_^HX(&+B`!"@X\/R_^O(___J
M\$<MZ4Q@G^5,4)_E!F"/X`50C^`%8$;@`'"@X0&`H.$"D*#A-?+_ZT9AL.'P
MA[T(`$"@XP0PE>0)(*#A"!"@X0<`H.$!0(3B,_\OX00`5N'W__\:\(>]Z'Q$
M`0!T1`$`'O\OX0@PG^4#,(_@`#"3Y5?R_^IT1@$`"$`MZ0B`O>@!``(`.P``
M`#X````+````/@```!`````^````)0```#X````S````/@````,````^````
M!@```#X````4````/@````X````^````#0```#X````D````/@```!(````^
M````)P```#X````"````/@```!@````^````"0```#X````*````/@``````
M````````)7,O)7,````O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O
M=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"]P<F]C+R5I
M+R5S`&5X90`N````4$%27U1%35``````4$%27U!23T=.04U%`````#H````E
M<R5S)7,``"\```!015),-4Q)0@````!015),3$E"`%!%4DPU3U!4`````%!%
M4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@``
M`%!!4E]$14)51P```%!!4E]#04-(10```%!!4E]'3$]"04Q?1$5"54<`````
M4$%27T=,3T)!3%]435!$25(```!005)?5$U01$E2``!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@````!005)?0TQ%04X]```Q````3$1?3$E"
M4D%265]0051(`%-94U1%30``)3`R>``````E<R5S)7,E<P````!P87(M````
M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I
M<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E
M<F%T:6]N*0H``%!!5$@`````<&%R;``````N<&%R`````"5S)7-C86-H92TE
M<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P`````8````
M<&5R;``````P````4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP-3(```!5
M;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE
M<G)N;STE:2D*`````"UE```M+0``55-%4@````!54T523D%-10````!414U0
M1$E2`%1-4``O=&UP`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@
M)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@
M<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1P87)?
M=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$
M('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`[
M"G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*
M;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M
M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*
M1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@
M=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD
M("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N
M97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@
M)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^
M9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD
M>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@
M)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@
M7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*
M8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^
M+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W
M;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F
M:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4
M*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["B1005)?34%'
M24,@/2`B7&Y005(N<&U<;B(["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY
M("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A
M=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?
M97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO
M(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7
M:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S
M971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*
M;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/#IR
M87<G+"`D<')O9VYA;64@;W(@;&%S=#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M
M<R`D<')O9VYA;64["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D
M;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@)&-H=6YK7W-I>F4I('L*)&UA9VEC
M7W!O<R`](#`["GT@96QS:68@*"AM>2`D;2`]("1S:7IE("4@)&-H=6YK7W-I
M>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D;3L*?2!E;'-E('L*
M)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H=6YK7W-I>F4["GT*=VAI;&4@*"1M
M86=I8U]P;W,@/CT@,"D@>PIS965K(%]&2"P@)&UA9VEC7W!O<RP@,#L*<F5A
M9"!?1D@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I
M.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P
M*2!["B1M86=I8U]P;W,@*ST@)&D["FQA<W0["GT*)&UA9VEC7W!O<R`M/2`D
M8VAU;FM?<VEZ93L*?0IL87-T(&EF("1M86=I8U]P;W,@/"`P.PIS965K(%]&
M2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F+"`T.PIS965K
M(%]&2"P@)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,#L*
M)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@
M7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A
M9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR
M96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L
M("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN
M9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M
M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D
M8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN
M*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@
M+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E
M7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F
M=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?
M5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8F%S96YA;64D
M97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I
M.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD36]D=6QE
M0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C
M+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*
M?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`
M7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF
M;R`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5](&]R(')E='5R;CL*
M)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H
M)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@
M>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG
M="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M
M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N
M("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O
M+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/#IR
M87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M
M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I
M;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H
M:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I
M6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]
M?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*
M<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE
M<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L
M971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D
M8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@
M+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?
M87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I
M.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D55
M4T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE
M<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=6
M6S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?
M8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@
M('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD[
M"FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T
M($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*
M96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC
M.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I
M=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A
M9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S
M92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G
M<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS
M:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D
M,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G
M<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@
M)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL
M92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M
M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C
M;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I
M.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U
M;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%2
M1U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*
M:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI
M9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@
M;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A
M<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*
M;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*
M?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP
M+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD
M+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ
M72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@
M;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A
M<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@
M-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B
M=68@97$@(E!+7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D
M;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE
M.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE
M.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F
M:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L
M(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1D871A7W!O<RD@>PIR96%D
M(%]&2"P@)&QO861E<BP@)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A;"`D+R`]
M('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"
M051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*9F]R96%C:"!M>2`D:V5Y("AS
M;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT
M.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA
M9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T
M(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[
M)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D
M,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R
M*3L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?
M;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@
M>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF
M:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV
M;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I
M;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ
M9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]
M("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?
M97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H
M<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E
M9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI
M('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R
M96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%
M+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T
M.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF
M("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH
M)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*
M?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N
M>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O
M7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)
M3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL
M92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@
M/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P
M96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A
M9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1F:#X["F-L;W-E("1F:#L*
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB
M961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA
M;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#
M;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*
M?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@
M*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T
M94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C
M;VYT96YT*2DL"B1C;VYT96YT*3L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M
M92)=*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II
M<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII
M9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;
M.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@
M)&9H+"`B/#IR87<B+"`D;W5T.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E
M("1F:#L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE
M7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C
M86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I
M.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO
M861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*)&9H+3YC;&]S93L*
M8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN
M960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL
M93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C
M:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P
M96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE
M9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM
M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&
M:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B
M)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@
M,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A
M8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"
M54=].PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0
M?2)=*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@
M8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z
M:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD[
M"FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N
M;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG
M.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN
M86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*
M;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?
M5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M
M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q
M6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI
M<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A
M8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B72D["B1M96UB
M97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U
M-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE
M<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U
M;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@
M72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@
M6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@
M0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ
M0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E
M($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S
M*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E
M<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D
M97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@
M=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E
M($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4[
M"G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U
M:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE
M=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F
M."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R
M7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P
M("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0
M(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S
M<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY
M("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE
M.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U
M:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G
M.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P
M<F]G;F%M92DI6SE=*2!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA
M;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*<V5E
M:R`D9F@L("TQ."P@,CL*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(#8["FEF
M("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIR96%D
M("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@
M(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21B=68B.PI]"F5L<V4@>PIM>2`D9&EG
M97-T(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$
M:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R
M;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T[
M"B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG
M97-T.PI]('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[
M4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT
M96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U
M8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`
M7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H
M+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B
M.PIO<&5N(&UY("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE(&]R(&1I92!Q<5M#
M86XG="!W<FET92`B)'1E;7!N86UE(CH@)"%=.PIP<FEN="`D9F@@)&-O;G1E
M;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F
M:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U
M;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?
M<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345]
M(&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M
M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0
M?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@
M>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N
M86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]0
M4D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI
M(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR
M971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?
M97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*
M?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E
M<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?
M5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<
M421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II
M9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X
M97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@
M?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D
M.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z
M.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P
M=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM
M?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345]
M(#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6
M>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92![
M"B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%
M1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T
M92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%
M04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/
M0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]
M"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@
M("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%2
M7T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%
M04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE
M;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU
M92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R
M;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN
M(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*
M<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@
M)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X
M<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R
M;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF
M="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G
M<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P
M<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S
M("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I
M9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`[
M"GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I
M9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D
M.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*``!P97)L>'-I
M+F,```!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(``````[````
M/@````L````^````$````#X````E````/@```#,````^`````P```#X````&
M````/@```!0````^````#@```#X````-````/@```"0````^````$@```#X`
M```G````/@````(````^````&````#X````)````/@````H````^````````
M```````HCO]_`0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$@9
M``#@&````0```"@#```!````.`,```$```!(`P```0```%(#```,````(!(`
M``T```"820``&0```*R-`0`;````!````!H```"PC0$`'`````0```#U_O]O
MK`$```4```!,"0``!@```)P"```*````U`0```L````0````%0`````````#
M````Q(X!``(```#H`0``%````!$````7````.!```!$```!8#P``$@```.``
M```3````"````!X````(````^___;P$```C^__]O^`X``/___V\#````\/__
M;R`.``#Z__]O$```````````````````````````````````````````````
M``````````"TC0$````````````L$@``+!(``"P2```L$@``+!(``"P2```L
M$@``+!(``"P2```L$@``+!(``"P2```L$@``+!(``"P2```L$@``+!(``"P2
M```L$@``+!(``"P2```L$@``+!(``"P2```L$@``+!(``"P2```L$@``+!(`
M`"P2```L$@``+!(``"P2```L$@``+!(``"P2```L$@``+!(``"P2```L$@``
M+!(``"P2```L$@``+!(``"P2```L$@``+!(``"P2```L$@``+!(``"P2```L
M$@``+!(``"P2```L$@``+!(``"P2```L$@``+!(``"P2```L$@``@$D`````
M````````````````````````````````````````($D````````@%0``````
M``````````````````20`0#_____8$T``)!*````````4$L``%1+``!430``
MF$H``%Q-````````0$T``$A-````````:$T``$=#0SH@*$1E8FEA;B`Q,2XR
M+C`M,3`I(#$Q+C(N,`!!*@```&%E86)I``$@````!35410`&!`@!"0$2!!,!
M%`$5`1<#&`$9`1H"`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL
M9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`
M+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT
M`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+D%232YE>&ED>``N96A?9G)A
M;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T
M80`N8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB=71E<P``````````````````
M``````````````````````````````````````L````!`````@```%0!``!4
M`0``$P```````````````0`````````3````!P````(```!H`0``:`$``"0`
M``````````````0`````````)@````<````"````C`$``(P!```@````````
M```````$`````````#0```#V__]O`@```*P!``"L`0``\`````4`````````
M!`````0````^````"P````(```"<`@``G`(``+`&```&`````P````0````0
M````1@````,````"````3`D``$P)``#4!``````````````!`````````$X`
M``#___]O`@```"`.```@#@``U@````4``````````@````(```!;````_O__
M;P(```#X#@``^`X``&`````&`````P````0`````````:@````D````"````
M6`\``%@/``#@````!0`````````$````"````',````)````0@```#@0```X
M$```Z`$```4````5````!`````@```!\`````0````8````@$@``(!(```P`
M``````````````0`````````=P````$````&````+!(``"P2``#P`@``````
M```````$````!````((````!````!@```"`5```@%0``>#0`````````````
M"`````````"(`````0````8```"820``F$D```@```````````````0`````
M````C@````$````"````H$D``*!)```(0``````````````$`````````)8`
M```!``!P@@```*B)``"HB0``"`````T`````````!`````````"A`````0``
M``(```"PB0``L(D```0```````````````0`````````JP````X````#````
MK(T!`*R-```$```````````````$````!````+<````/`````P```+"-`0"P
MC0``!```````````````!`````0```##````!@````,```"TC0$`M(T``!`!
M```&``````````0````(````S`````$````#````Q(X!`,2.```\`0``````
M```````$````!````-$````!`````P````"0`0``D```0```````````````
M!`````````#7````"`````,```!`D`$`0)```!00``````````````0`````
M````W`````$````P`````````$"0```?```````````````!`````0```.4`
M```#``!P``````````!?D```*P```````````````0`````````!`````P``
A````````````BI```/4```````````````$`````````
